<?php

class Clearscope_Plugin
{
  private $is_gutenberg;

  public function __construct()
  {
    add_action('current_screen', array($this, 'set_is_gutenberg'));
    add_action('admin_enqueue_scripts', array($this, 'enqueue_assets'));
    add_action('add_meta_boxes', array($this, 'add_meta_box'));
  }

  public function set_is_gutenberg()
  {
    if (get_current_screen()->is_block_editor()) {
      $this->is_gutenberg = true;
    } else {
      $this->is_gutenberg = false;
    }
  }

  public function enqueue_assets($hook)
  {
    global $wp_version, $clearscope_plugin_version;
    if (!$this->is_loadable()) {
      return;
    }
    $dependencies = array(
      'wp-plugins',
      'wp-element',
    );
    // Only load wp-edit-post as dependency on Gutenberg to work around Yoast breaking with wp-edit-post enabled
    // wp-edit-post is only used for PluginSidebar for Gutenberg
    if ($this->is_gutenberg) {
      array_push($dependencies, 'wp-edit-post');
    }
    // use `time()` as version argument to force cache-busting since we don't use a manifest for addons assets
    wp_enqueue_script('clearscope-wp-js', 'https://www.clearscope.io/packs/js/wp.js', $dependencies, time());
    wp_enqueue_style('clearscope-wp-css', 'https://www.clearscope.io/packs/css/wp.css', array(), time());
    wp_enqueue_style('metabox-css', plugins_url('css/metabox.css', __FILE__));
    wp_localize_script('clearscope-wp-js', 'wpEnv',
      array(
        'user' => wp_get_current_user()->to_array(),
        'wp_version' => $wp_version,
        'php_version' => phpversion(),
        'plugin_version' => $clearscope_plugin_version,
        'post' => get_post()->to_array(),
        'post_url' => get_edit_post_link(null, 'not display'),
        'is_gutenberg' => $this->is_gutenberg ? "true" : "false",
        'init_url' => $this->init_url()
      )
    );
  }

  public function add_meta_box()
  {
    if (!$this->is_gutenberg && $this->is_loadable()) {
      add_meta_box(
        'clearscope-meta',
        'Clearscope',
        array($this, 'meta_box_html')
      );
    }
  }

  public function meta_box_html()
  {
    echo '<div id="clearscope-sidebar" data-controller="sidebar" data-url="' . $this->init_url() . '" style="height:1000px;"></div>';
  }

  private function init_url()
  {
    return 'https://www.clearscope.io/addons/wp_report_links/' . urlencode(get_post()->to_array()['guid']);
  }

  private function is_loadable()
  {
    global $post;
    if($post){
      $post_type = get_post_type($post->ID);
      $public_post_types = get_post_types( array('public' => true ) );
      $loadable_post_types = array_keys(array_filter( $public_post_types, 'is_post_type_viewable' ));
      return in_array($post_type, $loadable_post_types);
    }
    return false;
  }
}
